@@ -11,6 +11,7 @@ DEFAULT_SETTINGS = dict(
     DEFAULT_LOG_FMT="[%(asctime)s %(levelname)s] %(message)s",
     LOGGING_LEVEL=logging.DEBUG,
     LOG_REQUESTS=False,
+    REDIRECT_STDOUT=True,
     LOG_FILE=None,
     SLOTS=[],
     PROCESS_NAME='thriftpool',
@@ -18,6 +19,9 @@ DEFAULT_SETTINGS = dict(
     PROTOCOL_FACTORY_CLS='thrift.protocol.TBinaryProtocol'
                          ':TBinaryProtocolAcceleratedFactory',
     SERVICE_PORT_RANGE=(10000, 20000),
+    WORKER_TYPE='sync',
+    WORKERS=1,
+    CONCURRENCY=1,
 )
 
 
