@@ -12,10 +12,18 @@ handler_method_guarded = Signal(providing_args=['fn'])
 listener_started = Signal(providing_args=['listener', 'slot', 'app'])
 
 
+#: All listener was started.
+listeners_started = Signal(providing_args=['app'])
+
+
 #: Listener was stopped.
 listener_stopped = Signal(providing_args=['listener', 'slot', 'app'])
 
 
+#: All listeners stopped.
+listeners_stopped = Signal(providing_args=['app'])
+
+
 #: Called before loggers are configured.
 setup_logging = Signal(providing_args=['root', 'logfile', 'loglevel'])
 
